@@ -32,7 +32,8 @@ settings.configure(
                     'django.contrib.contenttypes',
                     'django.contrib.sessions',
                     'django.contrib.admin',
-                    'payu',)
+                    'payu',),
+    SECRET_KEY='dummy'
 )
 
 
